@@ -1,7 +1,7 @@
 package Mouse::Role;
 use Mouse::Exporter; # enables strict and warnings
 
-our $VERSION = 'v2.4.9';
+use version; our $VERSION = version->declare('v2.5.0');
 
 use Carp         ();
 use Scalar::Util ();
@@ -115,6 +115,9 @@ sub init_meta{
     my $metaclass  = $args{metaclass}  || 'Mouse::Meta::Role';
 
     my $meta = $metaclass->initialize($class);
+    my $filename = Mouse::Util::module_notional_filename($meta->name);
+    $INC{$filename} = '(set by Mouse)'
+        unless exists $INC{$filename};
 
     $meta->add_method(meta => sub{
         $metaclass->initialize(ref($_[0]) || $_[0]);
@@ -137,7 +140,7 @@ Mouse::Role - The Mouse Role
 
 =head1 VERSION
 
-This document describes Mouse version v2.4.9
+This document describes Mouse version v2.5.0
 
 =head1 SYNOPSIS
 
